@@ -15,9 +15,9 @@
 ;    You should have received a copy of the GNU General Public License
 ;    along with TwinLisp; if not, write to the Free Software
 ;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-(in-package "TWINLISP")
+(cl:in-package "TWINLISP")
 ;; Oper+assignment operators
-(defmacro _+=_ (fst snd) `(setf ,fst (_+_ ,fst ,snd)))
-(defmacro _-=_ (fst snd) `(setf ,fst (_-_ ,fst ,snd)))
-(defmacro _*=_ (fst snd) `(setf ,fst (_*_ ,fst ,snd)))
-(defmacro _/=_ (fst snd) `(setf ,fst (_/_ ,fst ,snd)))
+(cl:defmacro _+=_ (fst snd) `(cl:setf ,fst (_+_ ,fst ,snd)))
+(cl:defmacro _-=_ (fst snd) `(cl:setf ,fst (_-_ ,fst ,snd)))
+(cl:defmacro _*=_ (fst snd) `(cl:setf ,fst (_*_ ,fst ,snd)))
+(cl:defmacro _/=_ (fst snd) `(cl:setf ,fst (_/_ ,fst ,snd)))
