@@ -19,4 +19,5 @@
 (cl:let* ((hPath (tl-home-path)) (dSep (tl-dir-sep))) ; TL's core methods, funcs, etc.
  (cl:require (concatenate 'string hPath "core" dSep "OtherMacs")) (cl:require (concatenate 'string hPath "core" dSep "ContainerTypesAndMacs")) (cl:require (concatenate 'string hPath "core" dSep "OperMacs")) (cl:require (concatenate 'string hPath "core" dSep "OtherFuncs")) (cl:require (concatenate 'string hPath "core" dSep "OperMeths")) (cl:require (concatenate 'string hPath "core" dSep "OtherMeths")) (cl:require (concatenate 'string hPath "core" dSep "ContainerMeths")) ; TL's translator
  (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslConst")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslStringReading")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslElemSearchFuncs")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslFormBuilding")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslFormWritting")) ; TL's loading func
- (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "LoaderMacs")))
+ (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "LoaderMacs")) ; Other useful functions that can now be defined using working TL
+ (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "omop")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "OtherMeths2")))
